@@ -4,7 +4,9 @@ import sys
 from array import array
 from collections import Counter, defaultdict, deque, UserDict, UserList
 from dataclasses import dataclass, fields, is_dataclass
+from inspect import isclass
 from itertools import islice
+import re
 from typing import (
     DefaultDict,
     TYPE_CHECKING,
@@ -57,6 +59,9 @@ if TYPE_CHECKING:
         RenderResult,
     )
 
+# Matches Jupyter's special methods
+_re_jupyter_repr = re.compile(f"^_repr_.+_$")
+
 
 def install(
     console: Optional["Console"] = None,
@@ -111,11 +116,10 @@ def install(
         # always skip rich generated jupyter renderables or None values
         if isinstance(value, JupyterRenderable) or value is None:
             return
-        # on jupyter rich display, if using one of the special representations dont use rich
-        if console.is_jupyter and any(attr.startswith("_repr_") for attr in dir(value)):
-            return
-
-        if hasattr(value, "_repr_mimebundle_"):
+        # on jupyter rich display, if using one of the special representations don't use rich
+        if console.is_jupyter and any(
+            _re_jupyter_repr.match(attr) for attr in dir(value)
+        ):
             return
 
         # certain renderables should start on a new line
@@ -135,6 +139,7 @@ def install(
                 margin=12,
             ),
             crop=crop,
+            new_line_start=True,
         )
 
     try:  # pragma: no cover
@@ -282,10 +287,10 @@ def is_expandable(obj: Any) -> bool:
     """Check if an object may be expanded by pretty print."""
     return (
         isinstance(obj, _CONTAINERS)
-        or (is_dataclass(obj) and not isinstance(obj, type))
-        or hasattr(obj, "__rich_repr__")
+        or (is_dataclass(obj))
+        or (hasattr(obj, "__rich_repr__"))
         or _is_attr_object(obj)
-    )
+    ) and not isclass(obj)
 
 
 @dataclass
@@ -301,11 +306,7 @@ class Node:
     is_tuple: bool = False
     children: Optional[List["Node"]] = None
     key_separator = ": "
-
-    @property
-    def separator(self) -> str:
-        """Get separator between items."""
-        return "" if self.last else ","
+    separator: str = ", "
 
     def iter_tokens(self) -> Iterable[str]:
         """Generate tokens for this node."""
@@ -324,7 +325,7 @@ class Node:
                     for child in self.children:
                         yield from child.iter_tokens()
                         if not child.last:
-                            yield ", "
+                            yield self.separator
                 yield self.close_brace
             else:
                 yield self.empty
@@ -380,12 +381,14 @@ class Node:
 class _Line:
     """A line in repr output."""
 
+    parent: Optional["_Line"] = None
     is_root: bool = False
     node: Optional[Node] = None
     text: str = ""
     suffix: str = ""
     whitespace: str = ""
     expanded: bool = False
+    last: bool = False
 
     @property
     def expandable(self) -> bool:
@@ -407,31 +410,39 @@ class _Line:
         whitespace = self.whitespace
         assert node.children
         if node.key_repr:
-            yield _Line(
+            new_line = yield _Line(
                 text=f"{node.key_repr}{node.key_separator}{node.open_brace}",
                 whitespace=whitespace,
             )
         else:
-            yield _Line(text=node.open_brace, whitespace=whitespace)
+            new_line = yield _Line(text=node.open_brace, whitespace=whitespace)
         child_whitespace = self.whitespace + " " * indent_size
         tuple_of_one = node.is_tuple and len(node.children) == 1
-        for child in node.children:
-            separator = "," if tuple_of_one else child.separator
+        for last, child in loop_last(node.children):
+            separator = "," if tuple_of_one else node.separator
             line = _Line(
+                parent=new_line,
                 node=child,
                 whitespace=child_whitespace,
                 suffix=separator,
+                last=last and not tuple_of_one,
             )
             yield line
 
         yield _Line(
             text=node.close_brace,
             whitespace=whitespace,
-            suffix="," if (tuple_of_one and not self.is_root) else node.separator,
+            suffix=self.suffix,
+            last=self.last,
         )
 
     def __str__(self) -> str:
-        return f"{self.whitespace}{self.text}{self.node or ''}{self.suffix}"
+        if self.last:
+            return f"{self.whitespace}{self.text}{self.node or ''}"
+        else:
+            return (
+                f"{self.whitespace}{self.text}{self.node or ''}{self.suffix.rstrip()}"
+            )
 
 
 def traverse(
@@ -463,7 +474,7 @@ def traverse(
             try:
                 obj_repr = repr(obj)
             except Exception as error:
-                obj_repr = f"<repr-error '{error}'>"
+                obj_repr = f"<repr-error {str(error)!r}>"
         return obj_repr
 
     visited_ids: Set[int] = set()
@@ -492,18 +503,29 @@ def traverse(
                 else:
                     yield arg
 
-        if hasattr(obj, "__rich_repr__"):
+        if hasattr(obj, "__rich_repr__") and not isclass(obj):
+            angular = getattr(obj.__rich_repr__, "angular", False)
             args = list(iter_rich_args(obj.__rich_repr__()))
+            class_name = obj.__class__.__name__
 
             if args:
                 children = []
                 append = children.append
-                node = Node(
-                    open_brace=f"{obj.__class__.__name__}(",
-                    close_brace=")",
-                    children=children,
-                    last=root,
-                )
+                if angular:
+                    node = Node(
+                        open_brace=f"<{class_name} ",
+                        close_brace=">",
+                        children=children,
+                        last=root,
+                        separator=" ",
+                    )
+                else:
+                    node = Node(
+                        open_brace=f"{class_name}(",
+                        close_brace=")",
+                        children=children,
+                        last=root,
+                    )
                 for last, arg in loop_last(args):
                     if isinstance(arg, tuple):
                         key, child = arg
@@ -518,7 +540,9 @@ def traverse(
                         append(child_node)
             else:
                 node = Node(
-                    value_repr=f"{obj.__class__.__name__}()", children=[], last=root
+                    value_repr=f"<{class_name}>" if angular else f"{class_name}()",
+                    children=[],
+                    last=root,
                 )
         elif _is_attr_object(obj):
             children = []
@@ -570,7 +594,7 @@ def traverse(
             and not isinstance(obj, type)
             and (
                 "__create_fn__" in obj.__repr__.__qualname__ or py_version == (3, 6)
-            )  # Check if __repr__ wasn't overriden
+            )  # Check if __repr__ wasn't overridden
         ):
             obj_id = id(obj)
             if obj_id in visited_ids:
